@@ -1354,6 +1354,8 @@ PatchBaselineIdentityTypeDef = TypedDict(
             "REDHAT_ENTERPRISE_LINUX",
             "SUSE",
             "CENTOS",
+            "ORACLE_LINUX",
+            "DEBIAN",
         ],
         "BaselineDescription": str,
         "DefaultBaseline": bool,
@@ -1554,6 +1556,8 @@ GetDefaultPatchBaselineResultTypeDef = TypedDict(
             "REDHAT_ENTERPRISE_LINUX",
             "SUSE",
             "CENTOS",
+            "ORACLE_LINUX",
+            "DEBIAN",
         ],
     },
     total=False,
@@ -1944,6 +1948,8 @@ GetPatchBaselineForPatchGroupResultTypeDef = TypedDict(
             "REDHAT_ENTERPRISE_LINUX",
             "SUSE",
             "CENTOS",
+            "ORACLE_LINUX",
+            "DEBIAN",
         ],
     },
     total=False,
@@ -2011,6 +2017,8 @@ GetPatchBaselineResultTypeDef = TypedDict(
             "REDHAT_ENTERPRISE_LINUX",
             "SUSE",
             "CENTOS",
+            "ORACLE_LINUX",
+            "DEBIAN",
         ],
         "GlobalFilters": PatchFilterGroupTypeDef,
         "ApprovalRules": PatchRuleGroupTypeDef,
@@ -2784,6 +2792,8 @@ UpdatePatchBaselineResultTypeDef = TypedDict(
             "REDHAT_ENTERPRISE_LINUX",
             "SUSE",
             "CENTOS",
+            "ORACLE_LINUX",
+            "DEBIAN",
         ],
         "GlobalFilters": PatchFilterGroupTypeDef,
         "ApprovalRules": PatchRuleGroupTypeDef,
